==> graphql-braid-0.23.9-sources.jar: com/atlassian/braid/transformation/BatchUtils.java <==
package com.atlassian.braid.transformation;

import graphql.language.Directive;
import graphql.language.DirectiveDefinition;
import graphql.language.DirectiveLocation;
import graphql.language.FieldDefinition;
import graphql.language.InputValueDefinition;
import graphql.language.NonNullType;
import graphql.language.StringValue;
import graphql.language.TypeName;

import javax.annotation.Nullable;

public class BatchUtils {
    public static final String BATCH_ALL = "batchall";
    public static final String NAME = "name";
    public static final String BATCH_ARG = "batchArg";
    public static final DirectiveDefinition BATCH_ALL_DIRECTIVE = DirectiveDefinition.newDirectiveDefinition()
            .name(BATCH_ALL)
            .directiveLocation(DirectiveLocation.newDirectiveLocation()
                    .name("FIELD_DEFINITION")
                    .build())
            .inputValueDefinition(InputValueDefinition.newInputValueDefinition()
                    .name(NAME)
                    .type(NonNullType.newNonNullType()
                            .type(TypeName.newTypeName()
                                    .name("String")
                                    .build())
                            .build())
                    .build())
            .inputValueDefinition(InputValueDefinition.newInputValueDefinition()
                    .name(BATCH_ARG)
                    .type(NonNullType.newNonNullType()
                            .type(TypeName.newTypeName()
                                    .name("String")
                                    .build())
                            .build())
                    .build())
            .build();

    @Nullable
    public static BatchMapping getBatchMapping(FieldDefinition fieldDefinition) {
        Directive batchAllDirective = fieldDefinition.getDirective(BATCH_ALL);
        if (batchAllDirective != null) {
            String field = fieldDefinition.getName();
            String batchField = ((StringValue) batchAllDirective.getArgument(NAME).getValue()).getValue();
            String batchFieldArg = ((StringValue) batchAllDirective.getArgument(BATCH_ARG).getValue()).getValue();

            return new BatchMapping(field, batchField, batchFieldArg);
        }

        return null;
    }
}

==> graphql-braid-0.23.16-sources.jar: com/atlassian/braid/transformation/BatchUtils.java <==
package com.atlassian.braid.transformation;

import graphql.language.Directive;
import graphql.language.DirectiveDefinition;
import graphql.language.DirectiveLocation;
import graphql.language.FieldDefinition;
import graphql.language.InputValueDefinition;
import graphql.language.NonNullType;
import graphql.language.StringValue;
import graphql.language.TypeName;

import javax.annotation.Nullable;

public class BatchUtils {
    public static final String BATCH_ALL = "batchall";
    public static final String NAME = "name";
    public static final String BATCH_ARG = "batchArg";
    public static final DirectiveDefinition BATCH_ALL_DIRECTIVE = DirectiveDefinition.newDirectiveDefinition()
            .name(BATCH_ALL)
            .directiveLocation(DirectiveLocation.newDirectiveLocation()
                    .name("FIELD_DEFINITION")
                    .build())
            .inputValueDefinition(InputValueDefinition.newInputValueDefinition()
                    .name(NAME)
                    .type(NonNullType.newNonNullType()
                            .type(TypeName.newTypeName()
                                    .name("String")
                                    .build())
                            .build())
                    .build())
            .inputValueDefinition(InputValueDefinition.newInputValueDefinition()
                    .name(BATCH_ARG)
                    .type(NonNullType.newNonNullType()
                            .type(TypeName.newTypeName()
                                    .name("String")
                                    .build())
                            .build())
                    .build())
            .build();

    @Nullable
    public static BatchMapping getBatchMapping(FieldDefinition fieldDefinition) {
        Directive batchAllDirective = fieldDefinition.getDirectives(BATCH_ALL).stream()
                .findAny()
                .orElse(null);
        if (batchAllDirective != null) {
            String field = fieldDefinition.getName();
            String batchField = ((StringValue) batchAllDirective.getArgument(NAME).getValue()).getValue();
            String batchFieldArg = ((StringValue) batchAllDirective.getArgument(BATCH_ARG).getValue()).getValue();

            return new BatchMapping(field, batchField, batchFieldArg);
        }

        return null;
    }
}
